==> haskell-hls-floskell-plugin-1.0.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-floskell-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-floskell-plugin-1.0.0.0-6svlJyemz0QJMzxJt7JCrs
key:                  hls-floskell-plugin-1.0.0.0-6svlJyemz0QJMzxJt7JCrs
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c2ce5426a72f31bc9f2ef4d6a4ea9378
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hls-floskell-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hls-floskell-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hls-floskell-plugin-1.0.0.0

hs-libraries:         HShls-floskell-plugin-1.0.0.0-6svlJyemz0QJMzxJt7JCrs
depends:
    base-4.15.0.0 floskell-0.10.5-4OMdzVtKes9CBBWUaQXeVh
    ghcide-1.4.0.3-8kpSynMGpWP7N8ikIMqQJg
    hls-plugin-api-1.1.0.2-CwnOJUgIsocG5Ee8QCiYGh
    lsp-types-1.2.0.0-5aUdub8d8uA3TNW6Pfx0bh text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-floskell-plugin-1.0.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-floskell-plugin
version:              1.0.0.0
visibility:           public
id:                   hls-floskell-plugin-1.0.0.0-57rgPc6DJgtBtIRvOMgWpa
key:                  hls-floskell-plugin-1.0.0.0-57rgPc6DJgtBtIRvOMgWpa
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  fe50189d28b31959786714deb4785399
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hls-floskell-plugin-1.0.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hls-floskell-plugin-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/hls-floskell-plugin-1.0.0.0

hs-libraries:         HShls-floskell-plugin-1.0.0.0-57rgPc6DJgtBtIRvOMgWpa
depends:
    base-4.15.0.0 floskell-0.10.5-8Y6iPvw7vx6FCTp4GK05b
    ghcide-1.4.0.3-749q4KqsnlR6JsUiRHq3I0
    hls-plugin-api-1.1.0.2-LE3vl1pj9MJKE9v2tsEc68
    lsp-types-1.2.0.0-1u8fs50cHeUHIYyLFAe5cW text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
